@@ -1,7 +1,7 @@
 import pytest
 from unittest.mock import call
 
-from pythonanywhere.api.students_api import StudentsAPI
+from pythonanywhere_core.students import StudentsAPI
 from pythonanywhere.students import Students
 
 
@@ -9,13 +9,13 @@ from pythonanywhere.students import Students
 class TestStudentsInit:
     def test_instantiates_correctly(self):
         students = Students()
-        assert type(students.api) == StudentsAPI
+        assert isinstance(students.api, StudentsAPI)
 
 
 @pytest.mark.students
 class TestStudentsGet:
     def test_returns_list_of_usernames_when_found_in_api_response(self, mocker):
-        mock_students_api_get = mocker.patch("pythonanywhere.api.students_api.StudentsAPI.get")
+        mock_students_api_get = mocker.patch("pythonanywhere.students.StudentsAPI.get")
         student_usernames = ["student1", "student2"]
         mock_students_api_get.return_value = {
             "students": [{"username": s} for s in student_usernames]
@@ -27,7 +27,7 @@ class TestStudentsGet:
         assert result == student_usernames
 
     def test_returns_empty_list_when_no_usernames_found_in_api_response(self, mocker):
-        mock_students_api_get = mocker.patch("pythonanywhere.api.students_api.StudentsAPI.get")
+        mock_students_api_get = mocker.patch("pythonanywhere.students.StudentsAPI.get")
         mock_students_api_get.return_value = {"students": []}
 
         result = Students().get()
@@ -43,7 +43,7 @@ class TestStudentsGet:
         ]
     )
     def test_uses_correct_grammar_in_log_messages(self, mocker, api_response, expected_wording):
-        mock_students_api_get = mocker.patch("pythonanywhere.api.students_api.StudentsAPI.get")
+        mock_students_api_get = mocker.patch("pythonanywhere.students.StudentsAPI.get")
         mock_students_api_get.return_value = api_response
         mock_snake = mocker.patch("pythonanywhere.students.snakesay")
         mock_info =  mocker.patch("pythonanywhere.students.logger.info")
@@ -57,7 +57,7 @@ class TestStudentsGet:
 @pytest.mark.students
 class TestStudentsDelete:
     def test_returns_true_and_informs_when_student_removed(self, mocker):
-        mock_students_api_delete = mocker.patch("pythonanywhere.api.students_api.StudentsAPI.delete")
+        mock_students_api_delete = mocker.patch("pythonanywhere.students.StudentsAPI.delete")
         mock_students_api_delete.return_value = True
         mock_snake = mocker.patch("pythonanywhere.students.snakesay")
         mock_info =  mocker.patch("pythonanywhere.students.logger.info")
@@ -70,7 +70,7 @@ class TestStudentsDelete:
         assert result is True
 
     def test_returns_false_and_warns_when_student_not_removed(self, mocker):
-        mock_students_api_delete = mocker.patch("pythonanywhere.api.students_api.StudentsAPI.delete")
+        mock_students_api_delete = mocker.patch("pythonanywhere.students.StudentsAPI.delete")
         mock_students_api_delete.side_effect = Exception("error msg")
         mock_students_api_delete.return_value = False
         mock_snake = mocker.patch("pythonanywhere.students.snakesay")
